@@ -3,11 +3,11 @@
 use strict;
 use warnings;
 
-use Test::Shared::Fixture::Wikibase::Datatype::Value::Item::WikidataEntity;
+use Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::WikidataEntity;
 use Wikibase::Datatype::Print::Value::Item;
 
 # Object.
-my $obj = Test::Shared::Fixture::Wikibase::Datatype::Value::Item::WikidataEntity->new;
+my $obj = Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::WikidataEntity->new;
 
 # Print out.
 print scalar Wikibase::Datatype::Print::Value::Item::print($obj);
