@@ -13,12 +13,12 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(check_datetime check_entity check_language
 	check_lexeme check_property check_sense);
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 sub check_datetime {
 	my ($self, $key) = @_;
 
-	if ($self->{$key} !~ m/^([\+\-]\d{4})\-(\d{2})\-(\d{2})T(\d{2}):(\d{2}):(\d{2})Z$/ms) {
+	if ($self->{$key} !~ m/^([\+\-]\d+)\-(\d{2})\-(\d{2})T(\d{2}):(\d{2}):(\d{2})Z$/ms) {
 		err "Parameter '$key' has bad date time.",
 			'Value', $self->{$key},
 		;
@@ -489,6 +489,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
